==> cloudwatch-1.115.0-sources.jar: software/amazon/awscdk/services/cloudwatch/Color.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * A set of standard colours that can be used in annotations in a GraphWidget.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T15:55:57.891Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.Color")
public class Color extends software.amazon.jsii.JsiiObject {

    protected Color(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Color(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        BLUE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "BLUE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        BROWN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "BROWN", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        GREEN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "GREEN", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        GREY = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "GREY", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        ORANGE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "ORANGE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        PINK = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "PINK", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        PURPLE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "PURPLE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        RED = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "RED", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Color() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * blue - hex #1f77b4.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String BLUE;

    /**
     * brown - hex #8c564b.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String BROWN;

    /**
     * green - hex #2ca02c.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String GREEN;

    /**
     * grey - hex #7f7f7f.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String GREY;

    /**
     * orange - hex #ff7f0e.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String ORANGE;

    /**
     * pink - hex #e377c2.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PINK;

    /**
     * purple - hex #9467bd.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PURPLE;

    /**
     * red - hex #d62728.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String RED;
}

==> cloudwatch-1.173.0-sources.jar: software/amazon/awscdk/services/cloudwatch/Color.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * A set of standard colours that can be used in annotations in a GraphWidget.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Dashboard dashboard;
 * Metric executionCountMetric;
 * Metric errorCountMetric;
 * dashboard.addWidgets(GraphWidget.Builder.create()
 *         .title("Executions vs error rate")
 *         .left(List.of(executionCountMetric))
 *         .right(List.of(errorCountMetric.with(MetricOptions.builder()
 *                 .statistic("average")
 *                 .label("Error rate")
 *                 .color(Color.GREEN)
 *                 .build())))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:27.213Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.Color")
public class Color extends software.amazon.jsii.JsiiObject {

    protected Color(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Color(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        BLUE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "BLUE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        BROWN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "BROWN", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        GREEN = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "GREEN", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        GREY = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "GREY", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        ORANGE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "ORANGE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        PINK = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "PINK", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        PURPLE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "PURPLE", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        RED = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudwatch.Color.class, "RED", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * blue - hex #1f77b4.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String BLUE;

    /**
     * brown - hex #8c564b.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String BROWN;

    /**
     * green - hex #2ca02c.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String GREEN;

    /**
     * grey - hex #7f7f7f.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String GREY;

    /**
     * orange - hex #ff7f0e.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String ORANGE;

    /**
     * pink - hex #e377c2.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PINK;

    /**
     * purple - hex #9467bd.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PURPLE;

    /**
     * red - hex #d62728.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String RED;
}
